@@ -22,28 +22,36 @@
 
 #include <Lum/Object.h>
 
-#include <Lum/Model/Integer.h>
+#include <Lum/Model/Number.h>
+#include <Lum/Model/Boolean.h>
 
 class Compass : public Lum::Control
 {
 private:
-  Lum::OS::ColorRef     arrowColor;
+  Lum::OS::ColorRef     arrowColorRight;
+  Lum::OS::ColorRef     arrowColorLeft;
   Lum::OS::ColorRef     arrowShadowColor;
   Lum::Model::DoubleRef model;
+  Lum::Model::BooleanRef arrowShowCourseDirection;	// north direction otherwise.
+  Lum::Model::ActionRef refreshTimer;
+  double                lastDirection;
 
 public:
   Compass();
 
   bool SetModel(Lum::Base::Model* model);
+  void SetShowCourseDirection(Lum::Model::Boolean *arrowShowCourse);
 
   void CalcSize();
-  void Draw(int x, int, size_t w, size_t h);
+  void Draw(Lum::OS::DrawInfo* draw,
+            int x, int, size_t w, size_t h);
 
   void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);
 
   static Compass* Create(Lum::Base::Model* model,
                          bool horizontalFlex=false,
-                         bool verticalFlex=false);
+                         bool verticalFlex=false,
+                         Lum::Model::Boolean* arrowShowCourse=NULL);
 };
 
 #endif
