@@ -21,10 +21,13 @@
 */
 
 #include <Lum/Model/Boolean.h>
-#include <Lum/Model/Integer.h>
+#include <Lum/Model/Number.h>
 
 extern Lum::Model::SizeTRef unitMode;
 extern Lum::Model::BooleanRef prohibitScreenBlanking;
+extern Lum::Model::BooleanRef compassShowCourseDirection;
+extern Lum::Model::BooleanRef compassShowRawGPSDirection;
+
 extern bool LoadConfig();
 extern bool SaveConfig();
 
