@@ -22,7 +22,7 @@
 
 #include <Lum/Object.h>
 
-#include <Lum/Model/Integer.h>
+#include <Lum/Model/Number.h>
 
 class Speed : public Lum::Control
 {
@@ -35,7 +35,8 @@ public:
   bool SetModel(Lum::Base::Model* model);
 
   void CalcSize();
-  void Draw(int x, int, size_t w, size_t h);
+  void Draw(Lum::OS::DrawInfo* draw,
+            int x, int, size_t w, size_t h);
 
   void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);
 
